@@ -1088,6 +1088,10 @@ GVApi::onGotRnr(bool success, const QByteArray &response, QNetworkReply *reply,
         if (pos == -1) {
             if (token->outParams["attempts"].toInt() != 0) {
                 Q_WARN("Too many attempts at relogin");
+
+                if (strReplyUrl.contains("setupMobile", Qt::CaseInsensitive)) {
+                    token->status = ATTS_SETUP_REQUIRED;
+                }
                 break;
             }
 
@@ -2147,7 +2151,8 @@ GVApi::onCallback(bool success, const QByteArray &response, QNetworkReply *,
         }
 
         if (strTemp != "true") {
-            Q_WARN("Failed to call back! response ok= ") << strTemp;
+            Q_WARN(QString("Failed to call back! response ok=%1. response='%2'")
+                   .arg(strTemp).arg(QString(response)));
             break;
         }
 
