@@ -95,7 +95,6 @@ QmlMainWindow::QmlMainWindow(QObject *parent)
 , tfaPinDlg(NULL)
 , textUsername(NULL)
 , textPassword(NULL)
-, infoBanner(NULL)
 , appPwDlg(NULL)
 , contactsPage(NULL)
 , inboxList(NULL)
@@ -294,11 +293,6 @@ QmlMainWindow::declStatusChanged(QDeclarativeView::Status status)
             break;
         }
 
-        infoBanner = getQMLObject ("InfoBanner");
-        if (NULL == infoBanner) {
-            break;
-        }
-
         contactsPage = getQMLObject ("ContactsPage");
         if (NULL == contactsPage) {
             break;
@@ -588,9 +582,6 @@ QmlMainWindow::uiLoginDone(int status, const QString &errStr)
     if (ATTS_SUCCESS == status) {
         return;
     }
-
-    infoBanner->setProperty ("text", errStr);
-    QMetaObject::invokeMethod (infoBanner, "show");
 }//QmlMainWindow::uiLoginDone
 
 void
@@ -734,6 +725,13 @@ QmlMainWindow::uiClearStatusMessage()
     QMetaObject::invokeMethod (statusBanner, "clearMessage");
 }//QmlMainWindow::uiClearStatusMessage
 
+void
+QmlMainWindow::uiShowMessageBox(const QString &msg)
+{
+    QMetaObject::invokeMethod (mainPageStack, "showMsgBox",
+                               Q_ARG (QVariant, QVariant(msg)));
+}//QmlMainWindow::uiShowMessageBox
+
 void
 QmlMainWindow::onUserTextBtnClicked(QString dest)
 {
